TimeCC: Crosscorrelation of a signal

Description Usage Arguments Value See Also Examples

View source: R/TimeCC.R

Description

This function returns the crosscorrelation (cc) estimates of a signal (time series) x of length N. Two types of estimators available : biased (default) and unbiased. In addition, this function has a plot utility to visualize the autocorrelation values with the default lag 50.

Usage

1
TimeCC(x, y)

Arguments

xy

Numeric, complex or logical vectors that indicate signals of length N each

biased

logical TRUE (default) for biased estimator

demean

logical to demean signal x before finding the ac (default TRUE)

normalize

logical to return the normalized ac values (default)

onesided

logical return the two-sided (default) or one-sided ac values

Value

A vector of crosscorrelation values of length 2N-1 (includes positive and negative lags.)

See Also

TimeAC() .

Examples

1
2
TimeCC(c(1,2,3,4,5,6),c(6,5,4,3,2,1))   
TimeCC(rnorm(20),rnorm(20))    

SignalEstimation/corrtest documentation built on Dec. 28, 2021, 12:13 a.m.